@@ -17,8 +17,8 @@
 #             the sdk resource objects.
 
 import datetime
+
 import munch
-import six
 
 from openstack import resource
 
@@ -117,7 +117,7 @@ def _split_filters(obj_name='', filters=None, **kwargs):
 
 
 def _to_bool(value):
-    if isinstance(value, six.string_types):
+    if isinstance(value, str):
         if not value:
             return False
         prospective = value.lower().capitalize()
@@ -140,7 +140,7 @@ def _pop_or_get(resource, key, default, strict):
         return resource.get(key, default)
 
 
-class Normalizer(object):
+class Normalizer:
     '''Mix-in class to provide the normalization functions.
 
     This is in a separate class just for on-disk source code organization
@@ -388,6 +388,9 @@ class Normalizer(object):
         ret['description'] = group.pop('description')
         ret['properties'] = group
 
+        if self._use_neutron_secgroups():
+            ret['stateful'] = group.pop('stateful', True)
+
         # Backwards compat with Neutron
         if not self.strict_mode:
             ret['tenant_id'] = project_id
@@ -1172,13 +1175,14 @@ class Normalizer(object):
 
     def _normalize_machine(self, machine):
         """Normalize Ironic Machine"""
-        machine = machine.copy()
+        if isinstance(machine, resource.Resource):
+            machine = machine._to_munch()
+        else:
+            machine = machine.copy()
 
         # Discard noise
         self._remove_novaclient_artifacts(machine)
 
-        # TODO(mordred) Normalize this resource
-
         return machine
 
     def _normalize_roles(self, roles):
