@@ -10,17 +10,13 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from openstack.identity import identity_service
-from openstack import resource2 as resource
+from openstack import resource
 
 
 class Version(resource.Resource):
     resource_key = 'version'
     resources_key = 'versions'
     base_path = '/'
-    service = identity_service.IdentityService(
-        version=identity_service.IdentityService.UNVERSIONED
-    )
 
     # capabilities
     allow_list = True
@@ -31,8 +27,12 @@ class Version(resource.Resource):
     updated = resource.Body('updated')
 
     @classmethod
-    def list(cls, session, paginated=False, **params):
-        resp = session.get(cls.base_path, endpoint_filter=cls.service,
+    def list(cls, session, paginated=False, base_path=None, **params):
+
+        if base_path is None:
+            base_path = cls.base_path
+
+        resp = session.get(base_path,
                            params=params)
         resp = resp.json()
         for data in resp[cls.resources_key]['values']:
